@@ -104,7 +104,7 @@ class QuickbooksCore(SitesCore):
         timer: datetime = datetime.now() + timedelta(seconds=timeout)
 
         while not is_success and timer > datetime.now():
-            self.__close_specific_windows('//button[@aria-label="Close"]')
+            # self.__close_specific_windows('//button[@aria-label="Close"]')
 
             if self.browser.does_page_contain_element(xpath):
                 try:
